@@ -933,7 +933,7 @@ GetGroupAttribute(interp, objIndex, fileName, attributePtrPtr)
     struct stat statBuf;
     struct group *groupPtr;
 
-    if (TclStat(fileName, &statBuf) != 0) {
+    if (stat(fileName, &statBuf) != 0) {
 	Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
 		"could not stat file \"", fileName, "\": ",
 		Tcl_PosixError(interp), (char *) NULL);
@@ -977,7 +977,7 @@ GetOwnerAttribute(interp, objIndex, fileName, attributePtrPtr)
     struct stat statBuf;
     struct passwd *pwPtr;
 
-    if (TclStat(fileName, &statBuf) != 0) {
+    if (stat(fileName, &statBuf) != 0) {
 	Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
 		"could not stat file \"", fileName, "\": ",
 		Tcl_PosixError(interp), (char *) NULL);
@@ -1021,14 +1021,14 @@ GetPermissionsAttribute(interp, objIndex, fileName, attributePtrPtr)
     struct stat statBuf;
     char returnString[6];
 
-    if (TclStat(fileName, &statBuf) != 0) {
+    if (stat(fileName, &statBuf) != 0) {
 	Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
 		"could not stat file \"", fileName, "\": ",
 		Tcl_PosixError(interp), (char *) NULL);
 	return TCL_ERROR;
     }
 
-    sprintf(returnString, "%0#5lo", (unsigned long) (statBuf.st_mode & 0x00007FFF));
+    sprintf(returnString, "%0#5lo", (statBuf.st_mode & 0x00007FFF));
 
     *attributePtrPtr = Tcl_NewStringObj(returnString, -1);
     
